<?php
/**
 * Adding support for WooCommerce Plugin
 */

if ( ! class_exists( 'woocommerce' ) ) {
    // Bail early if WooCommerce Plugin is not installed
    return;
}

if ( ! function_exists( 'catchbox_woocommerce_setup' ) ) :
    /**
     * Sets up support for various WooCommerce features.
     */
    function catchbox_woocommerce_setup() {
        add_theme_support( 'woocommerce' );

        $options = catchbox_get_options();

        if ( ! $options['disable_product_gallery_zoom'] ) {
            add_theme_support('wc-product-gallery-zoom');
        }

        if ( ! $options['disable_product_gallery_lightbox'] ) {
            add_theme_support('wc-product-gallery-lightbox');
        }

        if ( ! $options['disable_product_gallery_slider'] ) {
            add_theme_support('wc-product-gallery-slider');
        }
    }
endif; //catchbox_woocommerce_setup
add_action( 'after_setup_theme', 'catchbox_woocommerce_setup' );


/**
 * uses remove_action to remove the WooCommerce Wrapper and add_action to add Simple Catch Wrapper
 *
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );

if ( ! function_exists( 'catchbox_woocommerce_start' ) ) :
function catchbox_woocommerce_start() {
	echo '<div id="catchbox-woocommerce" class="hentry">';
}
endif; //catchbox_woocommerce_start
add_action( 'woocommerce_before_main_content', 'catchbox_woocommerce_start', 15 );

if ( ! function_exists( 'catchbox_woocommerce_end' ) ) :
function catchbox_woocommerce_end() {
	echo '</div></div></div>';
}
endif; //catchbox_woocommerce_end
add_action( 'woocommerce_after_main_content', 'catchbox_woocommerce_end', 15 );


function catchbox_woocommerce_options( $wp_customize ) {
    $defaults = catchbox_defaults();

    $wp_customize->add_setting( 'catchbox_options[woocommerce_layout]', array(
        'type'              => 'option',
        'default'           => $defaults['woocommerce_layout'],
        'sanitize_callback' => 'catchbox_sanitize_select',
    ) );

    $wp_customize->add_control( 'catchbox_theme_options[woocommerce_layout]', array(
        'priority' => 1,
        'choices'  => catchbox_layouts(),
        'label'    => esc_html__( 'Woocommerce Layout', 'catch-box-pro' ),
        'section'  => 'theme_layout',
        'type'     => 'select',
    ) );

    // WooCommerce Options
    $wp_customize->add_section( 'catchbox_woocommerce_options', array(
        'title'       => esc_html__( 'WooCommerce Options', 'catch-box-pro' ),
        'priority'    => 220,
        'panel'       => 'catchbox_theme_theme_options',
        'description' => esc_html__( 'Since these options are added via theme support, you will need to save and refresh the customizer to view the full effect.', 'catch-box-pro' ),
    ) );

    $wp_customize->add_setting( 'catchbox_theme_options[disable_product_gallery_zoom]', array(
        'default'           => $defaults['disable_product_gallery_zoom'],
        'sanitize_callback' => 'catchbox_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'catchbox_theme_options[disable_product_gallery_zoom]', array(
        'label'     => esc_html__( 'Check to disable Product Gallery Zoom', 'catch-box-pro' ),
        'section'   => 'catchbox_woocommerce_options',
        'type'      => 'checkbox',
    ) );

    $wp_customize->add_setting( 'catchbox_theme_options[disable_product_gallery_lightbox]', array(
        'default'           => $defaults['disable_product_gallery_lightbox'],
        'sanitize_callback' => 'catchbox_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'catchbox_theme_options[disable_product_gallery_lightbox]', array(
        'label'     => esc_html__( 'Check to disable Product Gallery Lightbox', 'catch-box-pro' ),
        'section'   => 'catchbox_woocommerce_options',
        'type'      => 'checkbox',
    ) );

    $wp_customize->add_setting( 'catchbox_theme_options[disable_product_gallery_slider]', array(
        'default'           => $defaults['disable_product_gallery_slider'],
        'sanitize_callback' => 'catchbox_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'catchbox_theme_options[disable_product_gallery_slider]', array(
        'label'     => esc_html__( 'Check to disable Product Gallery Slider', 'catch-box-pro' ),
        'section'   => 'catchbox_woocommerce_options',
        'type'      => 'checkbox',
    ) );
}
add_action( 'customize_register', 'catchbox_woocommerce_options' );