<?php
/**
 * @package Catch Themes
 * @subpackage Catch Box
 * @since Catch Box 3.6.7
 */


if( ! function_exists( 'catchbox_is_feed_url_present' ) ) :
	/**
	* Return true if feed url is present
	*
	* @since Catch Box 3.6.7
	*/
	function catchbox_is_feed_url_present( $control ) {
		$options = catchbox_get_options();

		return ( '' != $options['feed_url'] );
	}
endif;


if( ! function_exists( 'catchbox_is_header_code_present' ) ) :
	/**
	* Return true if header code is present
	*
	* @since Catch Box 3.6.7
	*/
	function catchbox_is_header_code_present( $control ) {
		$options = catchbox_get_options();

		return ( '' != $options['tracker_header'] );
	}
endif;


if( ! function_exists( 'catchbox_is_footer_code_present' ) ) :
	/**
	* Return true if footer code is present
	*
	* @since Catch Box 3.6.7
	*/
	function catchbox_is_footer_code_present( $control ) {
		$options = catchbox_get_options();

		return ( '' != $options['tracker_footer'] );
	}
endif;


if( ! function_exists( 'catchbox_is_slider_active' ) ) :
	/**
	* Return true if slider is active
	*
	* @since Catch Box 4.4
	*/
	function catchbox_is_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchbox_theme_options[enable_slider]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( 'enable-slider-allpage' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'enable-slider-homepage' == $enable ) );
	}
endif;

if( ! function_exists( 'catchbox_is_post_slider_active' ) ) :
	/**
	* Return true if post slider is active
	*
	* @since Catch Box 4.4
	*/
	function catchbox_is_post_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchbox_theme_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catchbox_theme_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( 'enable-slider-allpage' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'enable-slider-homepage' == $enable ) ) && 'post-slider' == $type );
	}
endif;

if( ! function_exists( 'catchbox_is_page_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Catch Box 4.4
	*/
	function catchbox_is_page_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchbox_theme_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catchbox_theme_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( 'enable-slider-allpage' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'enable-slider-homepage' == $enable ) ) && 'page-slider' == $type );
	}
endif;

if( ! function_exists( 'catchbox_is_image_slider_active' ) ) :
	/**
	* Return true if image slider is active
	*
	* @since Catch Box 4.4
	*/
	function catchbox_is_image_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchbox_theme_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catchbox_theme_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( 'enable-slider-allpage' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'enable-slider-homepage' == $enable ) ) && 'image-slider' == $type );
	}
endif;


if( ! function_exists( 'catchbox_is_category_slider_active' ) ) :
	/**
	* Return true if category slider is active
	*
	* @since Catch Box 4.4
	*/
	function catchbox_is_category_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catchbox_theme_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catchbox_theme_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( 'enable-slider-allpage' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'enable-slider-homepage' == $enable ) ) && 'category-slider' == $type );
	}
endif;


if( ! function_exists( 'catchbox_is_more_tag_accessible' ) ) :
	/**
	* Return true if more tag is accessible
	*
	* @since Catch Box 4.5
	*/
	function catchbox_is_more_tag_accessible( $control ) {
		//return true only if more tag accessible box is checked
		return ( '1' == $control->manager->get_setting( 'catchbox_theme_options[more_tag_accessible]' )->value() );
	}
endif;


if( ! function_exists( 'catchbox_is_more_tag_inaccessible' ) ) :
	/**
	* Return true if more tag is inaccessible
	*
	* @since Catch Box 4.5
	*/
	function catchbox_is_more_tag_inaccessible( $control ) {
		//return true only if more tag accessible box is unchecked
		return !$control->manager->get_setting( 'catchbox_theme_options[more_tag_accessible]' )->value();
	}
endif;